@@ -46,70 +46,73 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.admin.console.util.filestore;
 
-import java.net.URISyntaxException;
 import java.rmi.Naming;
 import java.util.ArrayList;
 import com.openexchange.admin.console.AdminParser;
+import com.openexchange.admin.console.CLIOption;
+import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.OXUtilInterface;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Filestore;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 
 /**
+ * CLT for listing file stores.
  *
  * @author d7,cutmasta
- *
  */
 public class ListFilestore extends FilestoreAbstraction {
 
-    public ListFilestore(final String[] args2) {
+    private CLIOption omitUsageOption = null;
 
+    public ListFilestore() {
+        super();
+    }
+
+    protected void execute(String[] args) {
         final AdminParser parser = new AdminParser("listfilestore");
-
         setOptions(parser);
         setCSVOutputOption(parser);
         try {
-            parser.ownparse(args2);
-
+            parser.ownparse(args);
             final Credentials auth = credentialsparsing(parser);
-
-            // get rmi ref
-            final OXUtilInterface oxutil = (OXUtilInterface) Naming.lookup(RMI_HOSTNAME +OXUtilInterface.RMI_NAME);
-
             String searchpattern = "*";
             if (parser.getOptionValue(this.searchOption) != null) {
                 searchpattern = (String) parser.getOptionValue(this.searchOption);
             }
-            // Setting the options in the dataobject
-
-            final Filestore[] filestores = oxutil.listFilestore(searchpattern, auth);
-
+            boolean omitUsage;
+            if (null == parser.getOptionValue(omitUsageOption)) {
+                omitUsage = false;
+            } else {
+                omitUsage = ((Boolean) parser.getOptionValue(omitUsageOption)).booleanValue();
+            }
+            final OXUtilInterface oxutil = (OXUtilInterface) Naming.lookup(RMI_HOSTNAME + OXUtilInterface.RMI_NAME);
+            final Filestore[] filestores = oxutil.listFilestore(searchpattern, auth, omitUsage);
             if (null != parser.getOptionValue(this.csvOutputOption)) {
                 precsvinfos(filestores);
             } else {
                 sysoutOutput(filestores);
             }
-
             sysexit(0);
         } catch (final Exception e) {
             printErrors(null, ctxid, e, parser);
         }
     }
 
-    private void sysoutOutput(final Filestore[] filestores) throws InvalidDataException, URISyntaxException {
+    private void sysoutOutput(final Filestore[] filestores) throws InvalidDataException {
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
         for (final Filestore filestore : filestores) {
-            data.add(makeCSVData(filestore, false));
+            data.add(makeCSVData(filestore));
         }
-
         //doOutput(new String[] { "3r", "35l", "7r", "8r", "7r", "7r", "7r" },
         doOutput(new String[] { "r", "l", "r", "r", "r", "r", "r" },
                  new String[] { "id", "path", "size", "reserved", "used", "maxctx", "curctx" }, data);
     }
 
-    private void precsvinfos(final Filestore[] filestores) throws URISyntaxException, InvalidDataException {
+    private void precsvinfos(final Filestore[] filestores) throws InvalidDataException {
         // needed for csv output, KEEP AN EYE ON ORDER!!!
         final ArrayList<String> columns = new ArrayList<String>();
         columns.add("id");
@@ -121,60 +124,51 @@ public class ListFilestore extends FilestoreAbstraction {
         columns.add("currentcontexts");
         // Needed for csv output
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
-
         for (final Filestore filestore : filestores) {
-            data.add(makeCSVData(filestore, true));
+            data.add(makeCSVData(filestore));
         }
-
         doCSVOutput(columns, data);
     }
 
-    public static void main(final String args[]) {
-        new ListFilestore(args);
+    public static void main(String[] args) {
+        new ListFilestore().execute(args);
     }
 
     private void setOptions(final AdminParser parser) {
         setDefaultCommandLineOptionsWithoutContextID(parser);
         setSearchOption(parser);
+        omitUsageOption = setShortLongOpt(parser, 'u', "omitUsage", "Do not load the usage of the file stores, which is expensive.", false, NeededQuadState.notneeded);
     }
 
-    private ArrayList<String> makeCSVData(final Filestore fstore, final boolean csv) throws URISyntaxException {
+    private static ArrayList<String> makeCSVData(final Filestore fstore) {
         final ArrayList<String> rea_data = new ArrayList<String>();
-
         rea_data.add(fstore.getId().toString());
-
         rea_data.add(fstore.getUrl());
-
         if (fstore.getSize() != null) {
             rea_data.add(fstore.getSize().toString());
         } else {
             rea_data.add(null);
         }
-
         if (fstore.getReserved() != null) {
             rea_data.add(fstore.getReserved().toString());
         } else {
             rea_data.add(null);
         }
-
         if (fstore.getUsed() != null) {
             rea_data.add(fstore.getUsed().toString());
         } else {
             rea_data.add(null);
         }
-
         if (fstore.getMaxContexts() != null) {
             rea_data.add(fstore.getMaxContexts().toString());
         } else {
             rea_data.add(null);
         }
-
         if (fstore.getCurrentContexts() != null) {
             rea_data.add(fstore.getCurrentContexts().toString());
         } else {
             rea_data.add(null);
         }
-
         return rea_data;
     }
 
