@@ -117,22 +117,22 @@ public class CreateLdap2SqlTables extends AbstractCreateTableImpl {
     private static final String createDelUserTable = "CREATE TABLE del_user ("
        + "cid INT4 UNSIGNED NOT NULL,"
        + "id INT4 UNSIGNED NOT NULL,"
-       + "imapServer VARCHAR(128),"
-       + "imapLogin VARCHAR(128),"
-       + "mail VARCHAR(256) NOT NULL,"
-       + "mailDomain VARCHAR(128),"
-       + "mailEnabled boolean NOT NULL,"
-       + "preferredLanguage VARCHAR(10) NOT NULL,"
-       + "shadowLastChange INTEGER NOT NULL,"
-       + "smtpServer VARCHAR(128),"
-       + "timeZone VARCHAR(128) NOT NULL,"
-       + "userPassword VARCHAR(128),"
+       + "imapServer VARCHAR(128) DEFAULT NULL,"
+       + "imapLogin VARCHAR(128) DEFAULT NULL,"
+       + "mail VARCHAR(256) NOT NULL DEFAULT '',"
+       + "mailDomain VARCHAR(128) DEFAULT NULL,"
+       + "mailEnabled boolean NOT NULL DEFAULT false,"
+       + "preferredLanguage VARCHAR(10) NOT NULL DEFAULT '',"
+       + "shadowLastChange INTEGER NOT NULL DEFAULT -1,"
+       + "smtpServer VARCHAR(128) DEFAULT NULL,"
+       + "timeZone VARCHAR(128) NOT NULL DEFAULT '',"
+       + "userPassword VARCHAR(128) DEFAULT NULL,"
        + "contactId INT4 UNSIGNED NOT NULL,"
-       + "passwordMech VARCHAR(32) NOT NULL,"
+       + "passwordMech VARCHAR(32) NOT NULL DEFAULT '',"
        + "uidNumber INT4 UNSIGNED NOT NULL,"
        + "gidNumber INT4 UNSIGNED NOT NULL,"
-       + "homeDirectory VARCHAR(128) NOT NULL,"
-       + "loginShell VARCHAR(128) NOT NULL,"
+       + "homeDirectory VARCHAR(128) NOT NULL DEFAULT '',"
+       + "loginShell VARCHAR(128) NOT NULL DEFAULT '',"
        + "PRIMARY KEY (cid, id)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
     
@@ -189,11 +189,11 @@ public class CreateLdap2SqlTables extends AbstractCreateTableImpl {
     private static final String createDelResourceTable = "CREATE TABLE del_resource ("
        + "cid INT4 UNSIGNED NOT NULL,"
        + "id INT4 UNSIGNED NOT NULL,"
-       + "identifier VARCHAR(128) NOT NULL,"
-       + "displayName VARCHAR(128) NOT NULL,"
-       + "mail VARCHAR(256),"
-       + "available boolean NOT NULL,"
-       + "description TEXT,"
+       + "identifier VARCHAR(128) NOT NULL DEFAULT '',"
+       + "displayName VARCHAR(128) NOT NULL DEFAULT '',"
+       + "mail VARCHAR(256) DEFAULT NULL,"
+       + "available boolean NOT NULL DEFAULT false,"
+       + "description TEXT DEFAULT NULL,"
        + "lastModified INT8 NOT NULL,"
        + "PRIMARY KEY (cid, id)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
