@@ -198,12 +198,12 @@ public class OXContextMySQLStorageCommon {
             return cs;
         } finally {
             closePreparedStatement(prep);
-            try {
-                if (oxdb_read != null) {
-                    cache.pushConnectionForContext(context_id, oxdb_read);
+            if (oxdb_read != null) {
+                try {
+                        cache.pushConnectionForContextAfterReading(context_id, oxdb_read);
+                } catch (final PoolException exp) {
+                    log.error("Pool Error pushing ox read connection to pool!",exp);
                 }
-            } catch (final PoolException exp) {
-                log.error("Pool Error pushing ox read connection to pool!",exp);
             }
         }
     }
@@ -444,6 +444,10 @@ public class OXContextMySQLStorageCommon {
                 public String getSchema() {
                     return db.getScheme();
                 }
+                @Override
+                public boolean isToConfigDB() {
+                    return true;
+                }
             });
         } catch (PoolException e) {
             throw new StorageException(e.getMessage(), e);
@@ -586,20 +590,18 @@ public class OXContextMySQLStorageCommon {
             checkAvailable = configdb_write_con.prepareStatement("SELECT 1 FROM login2context WHERE login_info = ?");
             stmt = configdb_write_con.prepareStatement("INSERT INTO login2context (cid,login_info) VALUES (?,?)");
             for (final String mapping : loginMappings) {
-                if (null != mapping) {
-                    checkAvailable.setString(1, mapping);
-                    found = checkAvailable.executeQuery();
-                    final boolean mappingTaken = found.next();
-                    found.close();
+                checkAvailable.setString(1, mapping);
+                found = checkAvailable.executeQuery();
+                final boolean mappingTaken = found.next();
+                found.close();
 
-                    if(mappingTaken) {
-                        throw new StorageException("Cannot map '"+mapping+"' to the newly created context. This mapping is already in use.");
-                    }
-
-                    stmt.setInt(1, ctxid.intValue());
-                    stmt.setString(2, mapping);
-                    stmt.executeUpdate();
+                if(mappingTaken) {
+                    throw new StorageException("Cannot map '"+mapping+"' to the newly created context. This mapping is already in use.");
                 }
+
+                stmt.setInt(1, ctxid);
+                stmt.setString(2, mapping);
+                stmt.executeUpdate();
             }
         } catch (final SQLException sql) {
             log.error("SQL Error", sql);
@@ -613,23 +615,24 @@ public class OXContextMySQLStorageCommon {
     }
 
     private void closeResultSet(final ResultSet rs) {
-        if (rs != null) {
-            try {
-                    rs.close();
-            } catch (final SQLException e) {
-                log.error(OXContextMySQLStorageCommon.LOG_ERROR_CLOSING_STATEMENT, e);
+        try {
+            if (rs != null) {
+                rs.close();
             }
+        } catch (final SQLException e) {
+            log.error(OXContextMySQLStorageCommon.LOG_ERROR_CLOSING_STATEMENT, e);
         }
     }
 
     private void closePreparedStatement(final PreparedStatement stmt) {
-        if (stmt != null) {
-            try {
-                    stmt.close();
-            } catch (final SQLException e) {
-                log.error(OXContextMySQLStorageCommon.LOG_ERROR_CLOSING_STATEMENT, e);
+        try {
+            if (stmt != null) {
+                stmt.close();
             }
+        } catch (final SQLException e) {
+            log.error(OXContextMySQLStorageCommon.LOG_ERROR_CLOSING_STATEMENT, e);
         }
     }
 
+
 }
