@@ -78,6 +78,50 @@ import com.openexchange.log.LogFactory;
 
 public class OXUtilMySQLStorageCommon {
 
+    /**
+     * High speed test for whitespace! Faster than the java one (from some testing).
+     *
+     * @return <code>true</code> if the indicated character is whitespace; otherwise <code>false</code>
+     */
+    public static boolean isWhitespace(final char c) {
+        switch (c) {
+        case 9: // 'unicode: 0009
+        case 10: // 'unicode: 000A'
+        case 11: // 'unicode: 000B'
+        case 12: // 'unicode: 000C'
+        case 13: // 'unicode: 000D'
+        case 28: // 'unicode: 001C'
+        case 29: // 'unicode: 001D'
+        case 30: // 'unicode: 001E'
+        case 31: // 'unicode: 001F'
+        case ' ': // Space
+            // case Character.SPACE_SEPARATOR:
+            // case Character.LINE_SEPARATOR:
+        case Character.PARAGRAPH_SEPARATOR:
+            return true;
+        default:
+            return false;
+        }
+    }
+
+    /**
+     * Checks for an empty string.
+     *
+     * @param string The string
+     * @return <code>true</code> if input is null or empty; else <code>false</code>
+     */
+    public static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
     private static final Log LOG = LogFactory.getLog(OXUtilMySQLStorageCommon.class);
 
     private static AdminCache cache = ClientAdminThread.cache;
